pub struct RestServer { /* private fields */ }Expand description
A server that serves a REST API for the bark Wallet
Implementations
Sourceimpl RestServer
impl RestServer
Sourcepub async fn start(
config: &Config,
auth_token: Option<AuthToken>,
wallet: Option<ServerWallet>,
on_wallet_create: Option<Arc<OnWalletCreate>>,
on_wallet_delete: Option<Arc<OnWalletDelete>>,
) -> Result<Self>
pub async fn start( config: &Config, auth_token: Option<AuthToken>, wallet: Option<ServerWallet>, on_wallet_create: Option<Arc<OnWalletCreate>>, on_wallet_delete: Option<Arc<OnWalletDelete>>, ) -> Result<Self>
Start a new RestServer with the given config and an optional ServerWallet
If no wallet is provided, the server will reject any action.
If auth_secrets is non-empty, token-based authentication is
enforced on all /api/v1 routes.